@@ -5,7 +5,7 @@ use Mojo::Loader qw/load_class/;
 use Storable qw/dclone/;
 use Class::Method::Modifiers qw/after/;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 has 'databases' => sub {
     [qw/Pg mysql SQLite Redis/]
@@ -60,10 +60,18 @@ sub _load_class_databases {
     for (@{$plugin->databases}) {
         if (defined $conf->{$_}) {
             my $class = 'Mojo::' . $_;
-            my $e     = load_class $class;
-            die "Loading '$class' failed: $e" if $e;
-
-            $databases->{lc($_)} = $class->new($conf->{$_});
+            
+            my $ref;
+            
+            if (ref($conf->{$_}) eq $class) {
+                $ref = $conf->{$_};
+            } else {
+                my $e     = load_class $class;
+                die "Loading '$class' failed: $e" if $e;
+                $ref = $class->new($conf->{$_});
+            }
+            
+            $databases->{lc($_)} = $ref;
         }
     }
 
@@ -151,6 +159,12 @@ All available options
         mysql        => 'mysql://user@/mydb',      # this will instantiate Mojo::mysql, in model get $self->mysql,
         SQLite       => 'sqlite:test.db',          # this will instantiate Mojo::SQLite, in model get $self->sqlite,
         Redis        => 'redis://localhost',       # this will instantiate Mojo::Redis, in model get $self->redis,
+        
+        # or using reference
+        Pg           => Mojo::Pg->new('postgresql://postgres@/test'),       # in model get $self->pg,
+        mysql        => Mojo::mysql->strict_mode('mysql://username@/test'), # in model get $self->mysql,
+        SQLite       => Mojo::SQLite->new('sqlite:test.db'),                # in model get $self->sqlite,
+        Redis        => Mojo::Redis->new("redis://localhost:6379/1"),       # in model get $self->redis,
 
         # Mojolicious::Plugin::Model
         namespaces   => ['MyApp::Model', 'MyApp::CLI::Model'],
